@@ -38,6 +38,11 @@ test_doc = '''<?xml version="1.0" encoding="iso-8859-1"?>
     </transform>
   
     <space name="space1">
+
+      <body name="body0">
+         <mass name="mass0" />
+      </body>
+
       <body name="body1" enabled="false" gravitymode="0">
         
         <transform scale="2.0">
@@ -308,7 +313,7 @@ class TestTreeNode(unittest.TestCase):
         self.node1.setODEObject(Class2())
         self.node2.setODEObject(Class2())
         self.node3.setODEObject(Class1())
-    
+
     def testGetName(self):
         self.assertEqual(self.node1.getName(), 'node1')
 
@@ -355,6 +360,10 @@ class TestParser(unittest.TestCase):
         self.p = parser.Parser()
         self.root = self.p.parseString(test_doc)
 
+        def assertEqualf(a, b):
+            self.assertEqual(feq(a, b), True)
+        self.assertEqualf = assertEqualf
+
 class TestWorldParser(TestParser):
     def testInstance(self):
         world = self.root.namedChild('world1').getODEObject()
@@ -383,7 +392,7 @@ class TestSpaceParser(TestParser):
         self.p3.setParams(spaceFactory=makeSpace)
         self.root3 = self.p3.parseString(doc)
         self.quadSpace = self.root3.namedChild('space1').getODEObject()
-        
+
     def testSimpleInstance(self):
         self.assert_(isinstance(self.simpleSpace, ode.SimpleSpace))
 
@@ -404,7 +413,7 @@ class TestBodyParser(TestParser):
         self.body1 = self.root.namedChild('body1').getODEObject()
         self.body3 = self.root.namedChild('body3').getODEObject()
         self.body6 = self.root.namedChild('body6').getODEObject()
-        
+
     def testInstance(self):
         self.assert_(isinstance(self.body1, ode.Body))
 
@@ -442,12 +451,16 @@ class TestBodyParser(TestParser):
     def testAngularVel(self):
         self.assertEqual(self.body1.getAngularVel(), (3.0, 2.0, 1.0))
 
-class TestMassParser(TestParser):    
+class TestMassParser(TestParser):
     def setUp(self):
         TestParser.setUp(self)
+        self.mass0 = self.root.namedChild('mass0').getODEObject()
         self.mass1 = self.root.namedChild('mass1').getODEObject()
         self.mass2 = self.root.namedChild('mass2').getODEObject()
 
+        self.ref1 = ode.Mass()
+        self.ref1.setSphere(1.0, 1.0)
+
         self.ref2 = ode.Mass()
         self.ref2.setSphere(2.0, 10.0)
         self.ref2.adjust(4.0)
@@ -455,6 +468,11 @@ class TestMassParser(TestParser):
     def testInstance(self):
         self.assert_(isinstance(self.mass1, ode.Mass))
 
+    def testDefault(self):
+        self.assertEqual(self.mass0.c, self.ref1.c)
+        self.assertEqual(self.mass0.I, self.ref1.I)
+        self.assertEqual(self.mass0.mass, self.ref1.mass)
+
     def testTotal(self):
         self.assertEqual(self.mass2.mass, 4.0)
 
@@ -576,40 +594,40 @@ class TestJointParser(TestParser):
         self.assertEqual(ref, axes)
 
     def testAxisParamLoStop(self):
-        self.assertEqual(self.joint6.getParam(ode.paramLoStop), 1.0)
+        self.assertEqualf(self.joint6.getParam(ode.paramLoStop), 1.0)
 
     def testAxisParamHiStop(self):
-        self.assertEqual(self.joint6.getParam(ode.paramHiStop), 2.0)
+        self.assertEqualf(self.joint6.getParam(ode.paramHiStop), 2.0)
 
     def testAxisParamVel(self):
-        self.assertEqual(self.joint6.getParam(ode.paramVel), 3.0)
+        self.assertEqualf(self.joint6.getParam(ode.paramVel), 3.0)
 
     def testAxisParamFMax(self):
-        self.assertEqual(self.joint6.getParam(ode.paramFMax), 4.0)
+        self.assertEqualf(self.joint6.getParam(ode.paramFMax), 4.0)
 
     def testAxisParamFudgeFactor(self):
-        self.assertEqual(self.joint6.getParam(ode.paramFudgeFactor), 0.5)
+        self.assertEqualf(self.joint6.getParam(ode.paramFudgeFactor), 0.5)
 
     def testAxisParamBounce(self):
-        self.assertEqual(self.joint6.getParam(ode.paramBounce), 6.0)
+        self.assertEqualf(self.joint6.getParam(ode.paramBounce), 6.0)
 
     def testAxisParamCFM(self):
-        self.assertEqual(self.joint6.getParam(ode.paramCFM), 7.0)
+        self.assertEqualf(self.joint6.getParam(ode.paramCFM), 7.0)
 
     def testAxisParamStopERP(self):
-        self.assertEqual(self.joint6.getParam(ode.paramStopERP), 8.0)
+        self.assertEqualf(self.joint6.getParam(ode.paramStopERP), 8.0)
 
     def testAxisParamStopCFM(self):
-        self.assertEqual(self.joint6.getParam(ode.paramStopCFM), 9.0)
+        self.assertEqualf(self.joint6.getParam(ode.paramStopCFM), 9.0)
 
     def testAxisParamSuspensionERP(self):
-        self.assertEqual(self.joint8.getParam(ode.paramSuspensionERP), 2.0)
+        self.assertEqualf(self.joint8.getParam(ode.paramSuspensionERP), 2.0)
 
     def testAxisParamSuspensionCFM(self):
-        self.assertEqual(self.joint8.getParam(ode.paramSuspensionCFM), 3.0)
+        self.assertEqualf(self.joint8.getParam(ode.paramSuspensionCFM), 3.0)
 
     def testAxis2FudgeFactor(self):
-        self.assertEqual(self.joint8.getParam(ode.ParamFudgeFactor2), 0.2)
+        self.assertEqualf(self.joint8.getParam(ode.ParamFudgeFactor2), 0.2)
 
 class TestGeomParser(TestParser):
     def setUp(self):
